==> flutter_tesseract_ocr-0.3.9.tar.gz: lib/web.dart <==
import 'dart:io';
import 'dart:js';

import 'package:flutter/services.dart';
import 'package:js/js.dart';
import 'package:js/js_util.dart';
import 'package:path_provider/path_provider.dart';

@JS('Tesseract.createWorker')
external dynamic createWorker();

// FlutterTesseractOcr Class
class FlutterTesseractOcr {
  static var worker = createWorker();

  /// image to  text
  ///```
  /// String _ocrText = await FlutterTesseractOcr.extractText(url, language: langs, args: {
  ///    "preserve_interword_spaces": "1",});
  ///```
  static extractText(String imagePath, {String? language, Map? args}) async {
    await promiseToFuture(worker.load());
    await promiseToFuture(worker.loadLanguage(language));
    await promiseToFuture(worker.initialize(language));

    await promiseToFuture(worker.setParameters(jsify(args!)));

    var rtn = await promiseToFuture(worker.recognize(imagePath, {}, worker.id));

    return rtn?.data?.text; //rtn?.data?.text;
  }

  /// image to  html text(hocr)
  ///```
  /// String _ocrHocr = await FlutterTesseractOcr.extractText(url, language: langs, args: {
  ///    "preserve_interword_spaces": "1",});
  ///```
  static Future<String> extractHocr(String imagePath,
      {String? language, Map? args}) async {
    await promiseToFuture(worker.load());
    await promiseToFuture(worker.loadLanguage(language));
    await promiseToFuture(worker.initialize(language));

    await promiseToFuture(worker.setParameters(
        jsify({...args!, "tessjs_create_hocr": "1"}), worker.id));

    var rtn = await promiseToFuture(worker.recognize(imagePath, {}, worker.id));

    return rtn?.data?.hocr;
  }

  //web not support
  static Future<String> getTessdataPath() async {
    return "";
  }

  //web not support
  static Future<String> _loadTessData() async {
    return "";
  }

  //web not support
  static Future _copyTessDataToAppDocumentsDirectory(
      String tessdataDirectory) async {}
}

==> flutter_tesseract_ocr-0.4.13.tar.gz: lib/web.dart <==
import 'dart:io';
import 'dart:js';
import 'dart:typed_data';

import 'package:flutter/services.dart';
import 'package:js/js.dart';
import 'package:js/js_util.dart';
import 'package:path_provider/path_provider.dart';

@JS('_extractText')
external dynamic _extractText(String imagePath, dynamic args);

// FlutterTesseractOcr Class
class FlutterTesseractOcr {
  /// image to  text
  ///```
  /// String _ocrText = await FlutterTesseractOcr.extractText(url, language: langs, args: {
  ///    "preserve_interword_spaces": "1",});
  ///```
  static extractText(String imagePath, {String? language, Map? args}) async {
    var promiseData =
        _extractText(imagePath, jsify({"language": language, "args": args!}));
    var rtn = await promiseToFuture(promiseData);
    return rtn;
  }

  /// image to  html text(hocr)
  ///```
  /// String _ocrHocr = await FlutterTesseractOcr.extractText(url, language: langs, args: {
  ///    "preserve_interword_spaces": "1",});
  ///```
  static Future<String> extractHocr(String imagePath,
      {String? language, Map? args}) async {
    var promiseData = _extractText(
        imagePath,
        jsify({
          "language": language,
          "args": {...args!, "tessjs_create_hocr": "1"}
        }));
    var rtn = await promiseToFuture(promiseData);
    return rtn;
  }

  /// extractTextLive (IOS)
  ///```
  /// extractTextLive(Uint8List)
  ///```
  static Future<String> extractTextLive(Uint8List image) async {
    return "only support IOS";
  }

  //web not support
  static Future<String> getTessdataPath() async {
    return "";
  }

  //web not support
  static Future<String> _loadTessData() async {
    return "";
  }

  //web not support
  static Future _copyTessDataToAppDocumentsDirectory(
      String tessdataDirectory) async {}
}
